package
Version:
v0.0.0-...-38eed3f
Opens a new window with list of versions in this module.
Published: Dec 21, 2023
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Books struct {
ID uint `gorm:"primary key;autoIncrement" json:"id"`
Author *string `json:"author"`
Title *string `json:"title"`
Publisher *string `json:"publisher"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.